import React, { ReactNode } from 'react';
import RemoteData from 'ts-remote-data';
interface RemoteSuspenseProps<T> {
    /**
     * The piece of data that the children need to render. To combine multiple
     * data dependencies in a single panel, use `RemoteData.all`.
     */
    data: RemoteData<T>;
    /**
     * The amount of time, in milliseconds, that the component will hold the
     * `LOADING` value before rendering `loadingFallback`. This has a default
     * value to avoid flashing loading indicators on loads that are shorter than
     * a person can perceive.
     */
    loadingTimeout?: number;
    /**
     * The elements to show while `data === RemoteData.LOADING`.
     */
    loadingFallback?: ReactNode;
    /**
     * The element to display when the remote data fails to load. This can
     * either be a React node, or it can be a function which accepts the
     * `error` property from the failure passed in the `data` prop.
     *
     * Both of the following are valid:
     *
     * * `<RemoteSuspense failureFallback={<ErrorMessage />} />`
     * * `<RemoteSuspense failureFallback={err => <Panel error={err} />}`
     */
    failureFallback?: ReactNode | ((error: unknown) => ReactNode);
    /**
     * Callback invoked when the data is ready.
     *
     * @param data The ready value of the `data` prop.
     */
    children(data: T): ReactNode;
}
/**
 * Analagous to React's native `Suspense` component, `RemoteSuspense` is a panel
 * that can be used to wrap elements which expect synchronously-available data
 * until their data dependencies resolve.
 *
 * It is expected that most projects will wrap this in their own panel component
 * which uses the project's standard loading indicator.
 */
export declare const RemoteSuspense: <T extends unknown>({ data, loadingTimeout, loadingFallback, failureFallback, ...props }: RemoteSuspenseProps<T>) => React.ReactElement<any, string | ((props: any) => React.ReactElement<any, string | any | (new (props: any) => React.Component<any, any, any>)> | null) | (new (props: any) => React.Component<any, any, any>)>;
export {};
