import { Dispatch, SetStateAction } from 'react';
import RemoteData from 'ts-remote-data';
/**
 * A representation of the states valid in the `usePromiseState` hook. Promises
 * have no native way of existing without being started, so `undefined` is used
 * to represent that case.
 */
declare type PromiseStateValue<T> = Promise<T> | undefined;
/**
 * A `useState` wrapper around `usePromise`. When a promise is created in
 * response to a user action and needs to be stored, this hook is appropriate.
 *
 * @param initialValue The initial state. When passing `undefined`, explicitly
 * declare the type of the value in the promise using the type parameter.
 *
 * @template T The value in the promise when it resolves.
 *
 * @returns A `RemoteData` representation of the current promise state, and a
 * setter function that can be used to update the promise and trigger a render.
 */
export declare const usePromiseState: <T>(initialValue?: Promise<T> | (() => PromiseStateValue<T>) | undefined) => [RemoteData<T>, Dispatch<SetStateAction<PromiseStateValue<T>>>];
export {};
