import RemoteData from 'ts-remote-data';
export interface RemoteLatestOptions {
    /**
     * When `true`, the hook will not report stale data to `ActivityIndicator`.
     * This can be used to prevent an activity indicator showing when a
     * component is mounted but out of view.
     */
    hideIndicator: boolean;
    /**
     * When set, the amount of time to keep stale data before exposing the
     * activity indicator.
     */
    indicatorTimeout: number;
}
/**
 * Once a component has completed its initial load, it may not want to return to
 * the loading state while waiting for a data update to complete. This hook
 * takes a `RemoteData` and decides whether to return that value or the previous
 * value.
 *
 * This hook integrates with `ActivityIndicator` to report when it's showing
 * stale data. This enables UI to automatically show a background loading
 * visual when stale data is being displayed.
 *
 * @returns The previous value if and only if 1) the current data is in the
 * `NOT_ASKED` or `LOADING` state and 2) the previous value was in the
 * ready-state.
 */
export declare const useRemoteLatest: <T>(data: RemoteData<T>, options?: Partial<RemoteLatestOptions>) => RemoteData<T>;
